@@ -43,6 +43,7 @@ def vsui_process():
                 atexit.register(exit_handler)
                 r = func(*args, **kwargs)
             except Exception as e:
+                logging.error(e)
                 r = disconnect()
             finally:
                 return r
@@ -51,17 +52,11 @@ def vsui_process():
 
 def safe_emit(event, data):
     ''' emit a socketio event with exception handling '''
-    global timeout_count, timeout_target
     try:
         sio.emit(event, data)
-        timeout_count = 0
-    except:
-        logging.warning(f'timeout {timeout_count} / {timeout_target}')
-        timeout_count += 1
-        if timeout_count >= timeout_target:
-            logging.error(f'socketio timeout, exiting!')
-            disconnect()
-            sys.exit(1)
+    except Exception as e:
+        logging.warning(e)
+        pass
 
 def connect(HOST : str = 'localhost', PORT : str = '8000') -> None:
     ''' initiate a socketio session with a server '''
